//Set Source Filters V1

//Purpose:
//Selects specific resource folders based on a sort selection

//Action Type: After Source Selection
//Prevent Default Action: No

//More info on Before Event Save actions and objects here:
//https://docs.dayback.com/article/140-custom-app-actions

//define which folders should be selected when a calendar is selected
//for example, When the 'Sevice Events' calendar is selected, the Team1 and Team2 resource folders will be selected.
var map = {
  'Sales Events' : [
    'Users'
  ],
  'Service Events' : [
    'Consulting',
    'Service'
  ]
};

//You shouldn't need to edit below this line

//determine which calendar we've selected
var thisCalendar = params.data ? params.data.item : false;

if(thisCalendar) {
  var name = thisCalendar.name;

  //if we've selected a mapped calendar then deselect the other mapped ones.
  if( map[thisCalendar.name] && thisCalendar.status.selected) {
    //determine which mapped calendars are selected
    var selected = selectedMapped();
    //deselect any selected ones that aren't the one we just clicked
    for ( var ii = 0 ; ii <selected.length ; ii++) {
      if(selected[ii].name!==name) {
        dbk.toggleCalendar(selected[ii]);
      }
    }

    //update resource selection bases on calendar selection
    setResourceSelection(thisCalendar,map);
    dbk.resetResources();

  }
}

function setResourceSelection(thisCalendar,map) {
  var resources = seedcodeCalendar.get('resources');
  var selectedFolders = map[thisCalendar.name];
  var unselectedFolders = [];
  for ( var property in map) {
    if(property!=thisCalendar.name) {
      unselectedFolders = unselectedFolders.concat(map[property]);
    }
  }
  for (var r = 0 ; r < resources.length ; r++) {
    for (var u = 0 ; u < unselectedFolders.length ; u++) {
      if(resources[r].status.selected && resources[r].folderName === unselectedFolders[u]) {
        resources[r].status.selected = false;
      }
    }
    for (var s = 0 ; s < selectedFolders.length ; s++) {
      if(!resources[r].status.selected && resources[r].folderName === selectedFolders[s]) {
        resources[r].status.selected = true;
      }
    }
  }
}

//helper function for returning an array of selected calendars that are mapped
function selectedMapped() {
  var calendars = seedcodeCalendar.get('schedules');
  var selected = [];
  for (var i = 0 ; i <calendars.length ; i++) {
    for( var mapping in map ) {
      if(mapping==calendars[i].name && calendars[i].status.selected) {
        selected.push(calendars[i]);
      }
    }
  }
  return selected;
}
